@@ -26,11 +26,11 @@ import sys
 import http.cookies
 import inspect
 import time
-from typing import Any, Dict, List, Tuple, Union, Callable
+from typing import Any, Dict, List, Tuple, Type, Union, Callable
 from simple_http_server.logger import get_logger
 
 name = "simple_http_server"
-version = "0.7.0"
+version = "0.9.2"
 
 _logger = get_logger("simple_http_server.__init__")
 
@@ -407,6 +407,88 @@ class Cookie(http.cookies.Morsel):
         return self.__required
 
 
+class WebsocketRequest:
+
+    def __init__(self):
+        self.headers: Dict[str, str] = {}  # Request headers
+        self.__cookies = Cookies()
+        self.query_string: str = ""  # Query String
+        self.path_values: Dict[str, str] = {}
+        self.path: str = ""  # Path
+        self.__parameters = {}  # Parameters, key-value array, merged by query string and request body if the `Content-Type` in request header is `application/x-www-form-urlencoded` or `multipart/form-data`
+        self.__parameter = {}  # Parameters, key-value, if more than one parameters with the same key, only the first one will be stored.
+
+    @property
+    def cookies(self) -> Cookies:
+        return self.__cookies
+
+    @property
+    def parameters(self) -> Dict[str, List[str]]:
+        return self.__parameters
+
+    @parameters.setter
+    def parameters(self, val: Dict[str, List[str]]):
+        self.__parameters = val
+        self.__parameter = {}
+        for k, v in self.__parameters.items():
+            self.__parameter[k] = v[0]
+
+    @property
+    def parameter(self) -> Dict[str, str]:
+        return self.__parameter
+
+    def get_parameter(self, key: str, default: str = None) -> str:
+        if key not in self.parameters.keys():
+            return default
+        else:
+            return self.parameter[key]
+
+
+class WebsocketSession:
+
+    @property
+    def id(self) -> str:
+        return ""
+
+    @property
+    def request(self) -> WebsocketRequest:
+        return None
+
+    @property
+    def is_closed(self) -> bool:
+        return False
+
+    def send(self, message: str):
+        pass
+
+    def send_pone(self, message: str):
+        pass
+
+    def send_ping(self, message: str):
+        pass
+
+    def close(self, reason: str):
+        pass
+
+
+class WebsocketHandler:
+
+    def on_handshake(self, request: WebsocketRequest = None):
+        return None
+
+    def on_open(self, session: WebsocketSession = None):
+        pass
+
+    def on_message(self, session: WebsocketSession = None, message_type: str = "", message: Any = None):
+        pass
+
+    def on_text_message(self, session: WebsocketSession = None, message: str = ""):
+        pass
+
+    def on_close(self, session: WebsocketSession = None, reason: str = ""):
+        pass
+
+
 def _get_class_of_method(method_defind):
     vals = vars(sys.modules[method_defind.__module__])
     for attr in method_defind.__qualname__.split('.')[:-1]:
@@ -514,6 +596,8 @@ _filters = []
 _ctrls = {}
 _ctrl_singletons = {}
 
+_ws_handlers = {}
+
 _session_facory: SessionFactory = None
 
 
@@ -587,6 +671,14 @@ def _get_singletion(clz, args, kwargs):
     return _ctrl_singletons[clz]
 
 
+def websocket_handler(endpoint=""):
+    def map(ws_class):
+        _ws_handlers[endpoint] = ws_class
+        return ws_class
+
+    return map
+
+
 def _get_request_mappings():
     mappings: List[ControllerFunction] = []
 
@@ -639,3 +731,7 @@ def _get_filters():
 
 def _get_session_factory() -> SessionFactory:
     return _session_facory
+
+
+def _get_websocket_handlers() -> Dict[str, Type]:
+    return _ws_handlers
